public inbox for linux-kernel@vger.kernel.org
 help / color / mirror / Atom feed
* [PATCH v1 0/1] Add TI TPS65214 PMIC Input Support
@ 2025-01-16 22:40 Shree Ramamoorthy
  2025-01-16 22:40 ` [PATCH v1 1/1] input: tps65214: Add support for TI TPS65214 PMIC Shree Ramamoorthy
  0 siblings, 1 reply; 5+ messages in thread
From: Shree Ramamoorthy @ 2025-01-16 22:40 UTC (permalink / raw)
  To: dmitry.torokhov, u.kleine-koenig, linux-input, linux-kernel
  Cc: m-leonard, praneeth

TPS65214 is a Power Management Integrated Circuit (PMIC) that has
significant register map overlap with TPS65215 and TPS65219. The series 
introduces TPS65214 and adds the device to the multi-PMIC support driver.

TPS65215 Driver Series:
GPIO: https://lore.kernel.org/all/20250113225530.124213-1-s-ramamoorthy@ti.com/
MFD: https://lore.kernel.org/all/20250113230750.124843-1-s-ramamoorthy@ti.com/
Reg: https://lore.kernel.org/all/20250113231018.125426-1-s-ramamoorthy@ti.com/
Input: https://lore.kernel.org/all/20241226220049.398794-1-s-ramamoorthy@ti.com/

TPS65219 Cleanup Series:
GPIO: https://lore.kernel.org/all/20241217204755.1011731-1-s-ramamoorthy@ti.com/
MFD: https://lore.kernel.org/all/20241217204935.1012106-1-s-ramamoorthy@ti.com/
Reg: https://lore.kernel.org/all/20241217204526.1010989-1-s-ramamoorthy@ti.com/

- TPS65214 is a Power Management IC with 3 Buck regulators and 2 LDOs.
- TPS65214 has 2 LDOS and 1 GPO, whereas TPS65219 has 4 LDOs and 2 GPOs.
- TPS65214's LDO1 maps to TPS65219's LDO3.
- A key difference between TPS65215 & TPS65214 are the LDO current and
  voltage output ranges and the configurable options available.
- The remaining features for both devices are the same.

TPS65214 TRM: https://www.ti.com/lit/pdf/slvud30

AM62L + TPS65214 Test Logs:
https://gist.github.com/ramamoorthyhs/0793f7813332d94423ca1baee02f62c9

Shree Ramamoorthy (1):
  input: tps65214: Add support for TI TPS65214 PMIC

 drivers/input/misc/tps65219-pwrbutton.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

-- 
2.43.0


^ permalink raw reply	[flat|nested] 5+ messages in thread

* [PATCH v1 1/1] input: tps65214: Add support for TI TPS65214 PMIC
  2025-01-16 22:40 [PATCH v1 0/1] Add TI TPS65214 PMIC Input Support Shree Ramamoorthy
@ 2025-01-16 22:40 ` Shree Ramamoorthy
  2025-01-17  9:23   ` Krzysztof Kozlowski
  0 siblings, 1 reply; 5+ messages in thread
From: Shree Ramamoorthy @ 2025-01-16 22:40 UTC (permalink / raw)
  To: dmitry.torokhov, u.kleine-koenig, linux-input, linux-kernel
  Cc: m-leonard, praneeth

Update descriptions to reflect this input driver  applies to TPS65214,
TPS65215, and TPS65219.

Signed-off-by: Shree Ramamoorthy <s-ramamoorthy@ti.com>
---
 drivers/input/misc/tps65219-pwrbutton.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/drivers/input/misc/tps65219-pwrbutton.c b/drivers/input/misc/tps65219-pwrbutton.c
index 27a8d10d81ac..385007608401 100644
--- a/drivers/input/misc/tps65219-pwrbutton.c
+++ b/drivers/input/misc/tps65219-pwrbutton.c
@@ -1,6 +1,6 @@
 // SPDX-License-Identifier: GPL-2.0
 //
 // Driver for TPS65215/TPS65219 Push Button
 //
 // Copyright (C) 2022 BayLibre Incorporated - https://www.baylibre.com/
 
@@ -145,6 +145,6 @@ static struct platform_driver tps65219_pb_driver = {
 };
 module_platform_driver(tps65219_pb_driver);
 
-MODULE_DESCRIPTION("TPS65215/TPS65219 Power Button");
+MODULE_DESCRIPTION("TPS65214/TPS65215/TPS65219 Power Button");
 MODULE_LICENSE("GPL");
 MODULE_AUTHOR("Markus Schneider-Pargmann <msp@baylibre.com");
@@ -1,6 +1,6 @@
 // SPDX-License-Identifier: GPL-2.0
 //
-// Driver for TPS65215/TPS65219 Push Button
+// TPS65214/TPS65215/TPS65219 Power Button Driver
 //
 // Copyright (C) 2022 BayLibre Incorporated - https://www.baylibre.com/
-- 
2.43.0


^ permalink raw reply related	[flat|nested] 5+ messages in thread

* Re: [PATCH v1 1/1] input: tps65214: Add support for TI TPS65214 PMIC
  2025-01-16 22:40 ` [PATCH v1 1/1] input: tps65214: Add support for TI TPS65214 PMIC Shree Ramamoorthy
@ 2025-01-17  9:23   ` Krzysztof Kozlowski
  2025-01-17 17:43     ` Dmitry Torokhov
  0 siblings, 1 reply; 5+ messages in thread
From: Krzysztof Kozlowski @ 2025-01-17  9:23 UTC (permalink / raw)
  To: Shree Ramamoorthy, dmitry.torokhov, u.kleine-koenig, linux-input,
	linux-kernel
  Cc: m-leonard, praneeth

On 16/01/2025 23:40, Shree Ramamoorthy wrote:
> Update descriptions to reflect this input driver  applies to TPS65214,
> TPS65215, and TPS65219.
> 
> Signed-off-by: Shree Ramamoorthy <s-ramamoorthy@ti.com>
> ---

That's just churn...

Best regards,
Krzysztof


^ permalink raw reply	[flat|nested] 5+ messages in thread

* Re: [PATCH v1 1/1] input: tps65214: Add support for TI TPS65214 PMIC
  2025-01-17  9:23   ` Krzysztof Kozlowski
@ 2025-01-17 17:43     ` Dmitry Torokhov
  2025-01-17 18:53       ` Shree Ramamoorthy
  0 siblings, 1 reply; 5+ messages in thread
From: Dmitry Torokhov @ 2025-01-17 17:43 UTC (permalink / raw)
  To: Krzysztof Kozlowski
  Cc: Shree Ramamoorthy, u.kleine-koenig, linux-input, linux-kernel,
	m-leonard, praneeth

On Fri, Jan 17, 2025 at 10:23:58AM +0100, Krzysztof Kozlowski wrote:
> On 16/01/2025 23:40, Shree Ramamoorthy wrote:
> > Update descriptions to reflect this input driver  applies to TPS65214,
> > TPS65215, and TPS65219.
> > 
> > Signed-off-by: Shree Ramamoorthy <s-ramamoorthy@ti.com>
> > ---
> 
> That's just churn...

Yes, when something is being reused we typically do not go back and list
all the new users unless there are other adjustments needed.

Thanks.

-- 
Dmitry

^ permalink raw reply	[flat|nested] 5+ messages in thread

* Re: [PATCH v1 1/1] input: tps65214: Add support for TI TPS65214 PMIC
  2025-01-17 17:43     ` Dmitry Torokhov
@ 2025-01-17 18:53       ` Shree Ramamoorthy
  0 siblings, 0 replies; 5+ messages in thread
From: Shree Ramamoorthy @ 2025-01-17 18:53 UTC (permalink / raw)
  To: Dmitry Torokhov, Krzysztof Kozlowski
  Cc: u.kleine-koenig, linux-input, linux-kernel, m-leonard, praneeth

Hi,

On 1/17/25 11:43 AM, Dmitry Torokhov wrote:
> On Fri, Jan 17, 2025 at 10:23:58AM +0100, Krzysztof Kozlowski wrote:
>> On 16/01/2025 23:40, Shree Ramamoorthy wrote:
>>> Update descriptions to reflect this input driver  applies to TPS65214,
>>> TPS65215, and TPS65219.
>>>
>>> Signed-off-by: Shree Ramamoorthy <s-ramamoorthy@ti.com>
>>> ---
>> That's just churn...
> Yes, when something is being reused we typically do not go back and list
> all the new users unless there are other adjustments needed.
>
> Thanks.

Thank you both for reviewing and the explanation.
I will drop this input series for the next version submitted.


-- 
Best,
Shree Ramamoorthy
PMIC Software Engineer


^ permalink raw reply	[flat|nested] 5+ messages in thread

end of thread, other threads:[~2025-01-17 18:54 UTC | newest]

Thread overview: 5+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2025-01-16 22:40 [PATCH v1 0/1] Add TI TPS65214 PMIC Input Support Shree Ramamoorthy
2025-01-16 22:40 ` [PATCH v1 1/1] input: tps65214: Add support for TI TPS65214 PMIC Shree Ramamoorthy
2025-01-17  9:23   ` Krzysztof Kozlowski
2025-01-17 17:43     ` Dmitry Torokhov
2025-01-17 18:53       ` Shree Ramamoorthy

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox